@@ -13,10 +13,6 @@
         <source>&amp;New</source>
         <translation type="unfinished">&amp;Nueva</translation>
     </message>
-    <message>
-        <source>Copy the currently selected address to the system clipboard</source>
-        <translation type="unfinished">Copiar la dirección seleccionada anguaño al portapapeles del sistema</translation>
-    </message>
     <message>
         <source>&amp;Copy</source>
         <translation type="unfinished">&amp;Copiar</translation>
@@ -101,7 +97,11 @@ La firma ye possible solamentu con direcciones del tipu 'legacy'.</translation>
         <source>Receiving addresses - %1</source>
         <translation type="unfinished">Recibiendo direcciones - %1</translation>
     </message>
-    </context>
+    <message>
+        <source>Exporting Failed</source>
+        <translation type="unfinished">Recibiendo direcciones</translation>
+    </message>
+</context>
 <context>
     <name>AddressTableModel</name>
     <message>
@@ -717,6 +717,18 @@ La firma ye possible solamentu con direcciones del tipu 'legacy'.</translation>
         <source>Pre-syncing Headers (%1%)…</source>
         <translation type="unfinished">Presincronizando encabezaos (%1%)…</translation>
     </message>
+    <message>
+        <source>Date: %1
+</source>
+        <translation type="unfinished">Fecha: %1
+</translation>
+    </message>
+    <message>
+        <source>Amount: %1
+</source>
+        <translation type="unfinished">Cantidá: %1
+</translation>
+    </message>
     </context>
 <context>
     <name>CoinControlDialog</name>
@@ -886,6 +898,10 @@ La firma ye possible solamentu con direcciones del tipu 'legacy'.</translation>
         <source>Address</source>
         <translation type="unfinished">Dirección</translation>
     </message>
+    <message>
+        <source>Exporting Failed</source>
+        <translation type="unfinished">Recibiendo direcciones</translation>
+    </message>
     </context>
 <context>
     <name>WalletFrame</name>
