@@ -12,10 +12,10 @@
 #include <util/bitset.h>
 #include <util/feefrac.h>
 
-#include <stdint.h>
+#include <cstdint>
 #include <numeric>
-#include <vector>
 #include <utility>
+#include <vector>
 
 namespace {
 
@@ -23,18 +23,6 @@ using namespace cluster_linearize;
 
 using TestBitSet = BitSet<32>;
 
-/** Check if a graph is acyclic. */
-template<typename SetType>
-bool IsAcyclic(const DepGraph<SetType>& depgraph) noexcept
-{
-    for (ClusterIndex i : depgraph.Positions()) {
-        if ((depgraph.Ancestors(i) & depgraph.Descendants(i)) != SetType::Singleton(i)) {
-            return false;
-        }
-    }
-    return true;
-}
-
 /** A formatter for a bespoke serialization for acyclic DepGraph objects.
  *
  * The serialization format outputs information about transactions in a topological order (parents
@@ -134,10 +122,10 @@ struct DepGraphFormatter
     static void Ser(Stream& s, const DepGraph<SetType>& depgraph)
     {
         /** Construct a topological order to serialize the transactions in. */
-        std::vector<ClusterIndex> topo_order;
+        std::vector<DepGraphIndex> topo_order;
         topo_order.reserve(depgraph.TxCount());
         for (auto i : depgraph.Positions()) topo_order.push_back(i);
-        std::sort(topo_order.begin(), topo_order.end(), [&](ClusterIndex a, ClusterIndex b) {
+        std::sort(topo_order.begin(), topo_order.end(), [&](DepGraphIndex a, DepGraphIndex b) {
             auto anc_a = depgraph.Ancestors(a).Count(), anc_b = depgraph.Ancestors(b).Count();
             if (anc_a != anc_b) return anc_a < anc_b;
             return a < b;
@@ -148,9 +136,9 @@ struct DepGraphFormatter
         SetType done;
 
         // Loop over the transactions in topological order.
-        for (ClusterIndex topo_idx = 0; topo_idx < topo_order.size(); ++topo_idx) {
+        for (DepGraphIndex topo_idx = 0; topo_idx < topo_order.size(); ++topo_idx) {
             /** Which depgraph index we are currently writing. */
-            ClusterIndex idx = topo_order[topo_idx];
+            DepGraphIndex idx = topo_order[topo_idx];
             // Write size, which must be larger than 0.
             s << VARINT_MODE(depgraph.FeeRate(idx).size, VarIntMode::NONNEGATIVE_SIGNED);
             // Write fee, encoded as an unsigned varint (odd=negative, even=non-negative).
@@ -158,9 +146,9 @@ struct DepGraphFormatter
             // Write dependency information.
             SetType written_parents;
             uint64_t diff = 0; //!< How many potential parent/child relations we have skipped over.
-            for (ClusterIndex dep_dist = 0; dep_dist < topo_idx; ++dep_dist) {
+            for (DepGraphIndex dep_dist = 0; dep_dist < topo_idx; ++dep_dist) {
                 /** Which depgraph index we are currently considering as parent of idx. */
-                ClusterIndex dep_idx = topo_order[topo_idx - 1 - dep_dist];
+                DepGraphIndex dep_idx = topo_order[topo_idx - 1 - dep_dist];
                 // Ignore transactions which are already known to be ancestors.
                 if (depgraph.Descendants(dep_idx).Overlaps(written_parents)) continue;
                 if (depgraph.Ancestors(idx)[dep_idx]) {
@@ -203,9 +191,9 @@ struct DepGraphFormatter
         DepGraph<SetType> topo_depgraph;
         /** Mapping from serialization order to cluster order, used later to reconstruct the
          *  cluster order. */
-        std::vector<ClusterIndex> reordering;
+        std::vector<DepGraphIndex> reordering;
         /** How big the entries vector in the reconstructed depgraph will be (including holes). */
-        ClusterIndex total_size{0};
+        DepGraphIndex total_size{0};
 
         // Read transactions in topological order.
         while (true) {
@@ -229,9 +217,9 @@ struct DepGraphFormatter
                 // Read dependency information.
                 auto topo_idx = reordering.size();
                 s >> VARINT(diff);
-                for (ClusterIndex dep_dist = 0; dep_dist < topo_idx; ++dep_dist) {
+                for (DepGraphIndex dep_dist = 0; dep_dist < topo_idx; ++dep_dist) {
                     /** Which topo_depgraph index we are currently considering as parent of topo_idx. */
-                    ClusterIndex dep_topo_idx = topo_idx - 1 - dep_dist;
+                    DepGraphIndex dep_topo_idx = topo_idx - 1 - dep_dist;
                     // Ignore transactions which are already known ancestors of topo_idx.
                     if (new_ancestors[dep_topo_idx]) continue;
                     if (diff == 0) {
@@ -298,9 +286,9 @@ template<typename SetType>
 void SanityCheck(const DepGraph<SetType>& depgraph)
 {
     // Verify Positions and PositionRange consistency.
-    ClusterIndex num_positions{0};
-    ClusterIndex position_range{0};
-    for (ClusterIndex i : depgraph.Positions()) {
+    DepGraphIndex num_positions{0};
+    DepGraphIndex position_range{0};
+    for (DepGraphIndex i : depgraph.Positions()) {
         ++num_positions;
         position_range = i + 1;
     }
@@ -309,7 +297,7 @@ void SanityCheck(const DepGraph<SetType>& depgraph)
     assert(position_range >= num_positions);
     assert(position_range <= SetType::Size());
     // Consistency check between ancestors internally.
-    for (ClusterIndex i : depgraph.Positions()) {
+    for (DepGraphIndex i : depgraph.Positions()) {
         // Transactions include themselves as ancestors.
         assert(depgraph.Ancestors(i)[i]);
         // If a is an ancestor of b, then b's ancestors must include all of a's ancestors.
@@ -318,8 +306,8 @@ void SanityCheck(const DepGraph<SetType>& depgraph)
         }
     }
     // Consistency check between ancestors and descendants.
-    for (ClusterIndex i : depgraph.Positions()) {
-        for (ClusterIndex j : depgraph.Positions()) {
+    for (DepGraphIndex i : depgraph.Positions()) {
+        for (DepGraphIndex j : depgraph.Positions()) {
             assert(depgraph.Ancestors(i)[j] == depgraph.Descendants(j)[i]);
         }
         // No transaction is a parent or child of itself.
@@ -337,7 +325,7 @@ void SanityCheck(const DepGraph<SetType>& depgraph)
             assert((depgraph.Descendants(child) & children).IsSubsetOf(SetType::Singleton(child)));
         }
     }
-    if (IsAcyclic(depgraph)) {
+    if (depgraph.IsAcyclic()) {
         // If DepGraph is acyclic, serialize + deserialize must roundtrip.
         std::vector<unsigned char> ser;
         VectorWriter writer(ser, 0);
@@ -360,7 +348,7 @@ void SanityCheck(const DepGraph<SetType>& depgraph)
         // In acyclic graphs, the union of parents with parents of parents etc. yields the
         // full ancestor set (and similar for children and descendants).
         std::vector<SetType> parents(depgraph.PositionRange()), children(depgraph.PositionRange());
-        for (ClusterIndex i : depgraph.Positions()) {
+        for (DepGraphIndex i : depgraph.Positions()) {
             parents[i] = depgraph.GetReducedParents(i);
             children[i] = depgraph.GetReducedChildren(i);
         }
@@ -392,7 +380,7 @@ void SanityCheck(const DepGraph<SetType>& depgraph)
 
 /** Perform a sanity check on a linearization. */
 template<typename SetType>
-void SanityCheck(const DepGraph<SetType>& depgraph, Span<const ClusterIndex> linearization)
+void SanityCheck(const DepGraph<SetType>& depgraph, std::span<const DepGraphIndex> linearization)
 {
     // Check completeness.
     assert(linearization.size() == depgraph.TxCount());
@@ -406,6 +394,29 @@ void SanityCheck(const DepGraph<SetType>& depgraph, Span<const ClusterIndex> lin
     }
 }
 
+inline uint64_t MaxOptimalLinearizationIters(DepGraphIndex cluster_count)
+{
+    // We assume sqrt(2^k)+1 candidate-finding iterations per candidate to be found, plus ceil(k/4)
+    // startup cost when up to k unlinearization transactions remain, plus ceil(n^2/64) overall
+    // startup cost in Linearize. Thus, we can compute the upper bound for a whole linearization
+    // (summing for k=1..n) using the Python expression:
+    //
+    //   [sum((k+3)//4 + math.isqrt(2**k) + 1 for k in range(1, n + 1)) + (n**2 + 63) // 64 for n in range(0, 65)]
+    //
+    // Note that these are just assumptions, as the proven upper bound grows with 2^k, not
+    // sqrt(2^k).
+    static constexpr uint64_t MAX_OPTIMAL_ITERS[65] = {
+        0, 4, 8, 12, 18, 26, 37, 51, 70, 97, 133, 182, 251, 346, 480, 666, 927, 1296, 1815, 2545,
+        3576, 5031, 7087, 9991, 14094, 19895, 28096, 39690, 56083, 79263, 112041, 158391, 223936,
+        316629, 447712, 633086, 895241, 1265980, 1790280, 2531747, 3580335, 5063259, 7160424,
+        10126257, 14320575, 20252230, 28640853, 40504150, 57281380, 81007962, 114562410, 162015557,
+        229124437, 324030718, 458248463, 648061011, 916496483, 1296121563, 1832992493, 2592242635,
+        3665984477, 5184484745, 7331968412, 10368968930, 14663936244
+    };
+    assert(cluster_count < sizeof(MAX_OPTIMAL_ITERS) / sizeof(MAX_OPTIMAL_ITERS[0]));
+    return MAX_OPTIMAL_ITERS[cluster_count];
+}
+
 } // namespace
 
 #endif // BITCOIN_TEST_UTIL_CLUSTER_LINEARIZE_H
