@@ -1,4 +1,4 @@
-// Copyright (c) 2023 The Bitcoin Core developers
+// Copyright (c) 2023-present The Bitcoin Core developers
 // Distributed under the MIT software license, see the accompanying
 // file COPYING or http://www.opensource.org/licenses/mit-license.php.
 
@@ -10,7 +10,7 @@
 #include <test/util/random.h>
 #include <uint256.h>
 
-#include <stdint.h>
+#include <cstdint>
 #include <utility>
 
 COutPoint AddTestCoin(FastRandomContext& rng, CCoinsViewCache& coins_view)
